==> pdf-model-arlington-1.25.44-sources.jar: org/verapdf/model/alayer/AXRefStream.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AXRefStream extends AObject {
	













	/**
	*/
	public Boolean getcontainsAuthCode();

	/**
	*/
	public Boolean getisAuthCodeIndirect();

	/**
	*/
	public String getAuthCodeType();

	/**
	*/
	public Boolean getAuthCodeHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsDL();

	/**
	*/
	public String getDLType();

	/**
	*/
	public Boolean getDLHasTypeInteger();

	/**
	*/
	public Long getDLIntegerValue();

	/**
	*/
	public Boolean getcontainsDecodeParms();

	/**
	*/
	public Boolean getisDecodeParmsIndirect();

	/**
	*/
	public String getDecodeParmsType();

	/**
	*/
	public Boolean getDecodeParmsHasTypeArray();

	/**
	*/
	public Boolean getDecodeParmsHasTypeDictionary();

	/**
	*/
	public Long getDecodeParmsArraySize();

	/**
	*/
	public Boolean getcontainsEncrypt();

	/**
	*/
	public String getEncryptType();

	/**
	*/
	public Boolean getEncryptHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public String getFType();

	/**
	*/
	public Boolean getFHasTypeDictionary();

	/**
	*/
	public Boolean getFHasTypeString();

	/**
	*/
	public Boolean getcontainsFDecodeParms();

	/**
	*/
	public String getFDecodeParmsType();

	/**
	*/
	public Boolean getFDecodeParmsHasTypeArray();

	/**
	*/
	public Boolean getFDecodeParmsHasTypeDictionary();

	/**
	*/
	public Long getFDecodeParmsArraySize();

	/**
	*/
	public Boolean getcontainsFFilter();

	/**
	*/
	public String getFFilterType();

	/**
	*/
	public Boolean getFFilterHasTypeArray();

	/**
	*/
	public Boolean getFFilterHasTypeName();

	/**
	*/
	public String getFFilterNameValue();

	/**
	*/
	public Long getFFilterArraySize();

	/**
	*/
	public Boolean getcontainsFilter();

	/**
	*/
	public Boolean getisFilterIndirect();

	/**
	*/
	public String getFilterType();

	/**
	*/
	public Boolean getFilterHasTypeArray();

	/**
	*/
	public Boolean getFilterHasTypeName();

	/**
	*/
	public String getFilterNameValue();

	/**
	*/
	public Long getFilterArraySize();

	/**
	*/
	public String getFilterEntriesString();

	/**
	*/
	public Boolean getcontainsID();

	/**
	*/
	public Boolean getisentryIDIndirect();

	/**
	*/
	public String getentryIDType();

	/**
	*/
	public Boolean getentryIDHasTypeArray();

	/**
	*/
	public Boolean getcontainsIndex();

	/**
	*/
	public Boolean getisIndexIndirect();

	/**
	*/
	public String getIndexType();

	/**
	*/
	public Boolean getIndexHasTypeArray();

	/**
	*/
	public Boolean getisIndexArraySortAscending2();

	/**
	*/
	public Long getIndexArraySize();

	/**
	*/
	public Boolean getcontainsInfo();

	/**
	*/
	public Boolean getisInfoIndirect();

	/**
	*/
	public String getInfoType();

	/**
	*/
	public Boolean getInfoHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsLength();

	/**
	*/
	public String getLengthType();

	/**
	*/
	public Boolean getLengthHasTypeInteger();

	/**
	*/
	public Long getLengthIntegerValue();

	/**
	*/
	public Boolean getcontainsPrev();

	/**
	*/
	public Boolean getisPrevIndirect();

	/**
	*/
	public String getPrevType();

	/**
	*/
	public Boolean getPrevHasTypeInteger();

	/**
	*/
	public Long getPrevIntegerValue();

	/**
	*/
	public Boolean getcontainsRoot();

	/**
	*/
	public Boolean getisRootIndirect();

	/**
	*/
	public String getRootType();

	/**
	*/
	public Boolean getRootHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsSize();

	/**
	*/
	public Boolean getisSizeIndirect();

	/**
	*/
	public String getSizeType();

	/**
	*/
	public Boolean getSizeHasTypeInteger();

	/**
	*/
	public Long getSizeIntegerValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getisTypeIndirect();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsW();

	/**
	*/
	public Boolean getisWIndirect();

	/**
	*/
	public String getWType();

	/**
	*/
	public Boolean getWHasTypeArray();

	/**
	*/
	public Long getEncryptVIntegerValue();

	/**
	*/
	public Boolean getEncryptVHasTypeInteger();

	/**
	*/
	public Boolean getcontainstrailerCatalogPieceInfo();

	/**
	*/
	public Boolean getcontainstrailerInfoModDate();

	/**
	*/
	public Boolean gethasExtensionISO_TS_32004();
}

==> pdf-model-arlington-1.25.50-sources.jar: org/verapdf/model/alayer/AXRefStream.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AXRefStream extends AObject {
	














	/**
	*/
	public Boolean getcontainsAdditionalStreams();

	/**
	*/
	public Boolean getisAdditionalStreamsIndirect();

	/**
	*/
	public String getAdditionalStreamsType();

	/**
	*/
	public Boolean getAdditionalStreamsHasTypeArray();

	/**
	*/
	public Long getAdditionalStreamsArraySize();

	/**
	*/
	public Boolean getcontainsAuthCode();

	/**
	*/
	public Boolean getisAuthCodeIndirect();

	/**
	*/
	public String getAuthCodeType();

	/**
	*/
	public Boolean getAuthCodeHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsDL();

	/**
	*/
	public Boolean getisDLIndirect();

	/**
	*/
	public String getDLType();

	/**
	*/
	public Boolean getDLHasTypeInteger();

	/**
	*/
	public Long getDLIntegerValue();

	/**
	*/
	public Boolean getcontainsDecodeParms();

	/**
	*/
	public Boolean getisDecodeParmsIndirect();

	/**
	*/
	public String getDecodeParmsType();

	/**
	*/
	public Boolean getDecodeParmsHasTypeArray();

	/**
	*/
	public Boolean getDecodeParmsHasTypeDictionary();

	/**
	*/
	public Long getDecodeParmsArraySize();

	/**
	*/
	public Boolean getcontainsDocChecksum();

	/**
	*/
	public Boolean getisDocChecksumIndirect();

	/**
	*/
	public String getDocChecksumType();

	/**
	*/
	public Boolean getDocChecksumHasTypeName();

	/**
	*/
	public Boolean getcontainsEncrypt();

	/**
	*/
	public Boolean getisEncryptIndirect();

	/**
	*/
	public String getEncryptType();

	/**
	*/
	public Boolean getEncryptHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsF();

	/**
	*/
	public String getFType();

	/**
	*/
	public Boolean getFHasTypeDictionary();

	/**
	*/
	public Boolean getFHasTypeString();

	/**
	*/
	public Boolean getcontainsFDecodeParms();

	/**
	*/
	public String getFDecodeParmsType();

	/**
	*/
	public Boolean getFDecodeParmsHasTypeArray();

	/**
	*/
	public Boolean getFDecodeParmsHasTypeDictionary();

	/**
	*/
	public Long getFDecodeParmsArraySize();

	/**
	*/
	public Boolean getcontainsFFilter();

	/**
	*/
	public String getFFilterType();

	/**
	*/
	public Boolean getFFilterHasTypeArray();

	/**
	*/
	public Boolean getFFilterHasTypeName();

	/**
	*/
	public String getFFilterNameValue();

	/**
	*/
	public Long getFFilterArraySize();

	/**
	*/
	public Boolean getcontainsFilter();

	/**
	*/
	public Boolean getisFilterIndirect();

	/**
	*/
	public String getFilterType();

	/**
	*/
	public Boolean getFilterHasTypeArray();

	/**
	*/
	public Boolean getFilterHasTypeName();

	/**
	*/
	public String getFilterNameValue();

	/**
	*/
	public Long getFilterArraySize();

	/**
	*/
	public String getFilterEntriesString();

	/**
	*/
	public Boolean getcontainsID();

	/**
	*/
	public Boolean getisentryIDIndirect();

	/**
	*/
	public String getentryIDType();

	/**
	*/
	public Boolean getentryIDHasTypeArray();

	/**
	*/
	public Boolean getcontainsIndex();

	/**
	*/
	public Boolean getisIndexIndirect();

	/**
	*/
	public String getIndexType();

	/**
	*/
	public Boolean getIndexHasTypeArray();

	/**
	*/
	public Boolean getisIndexArraySortAscending2();

	/**
	*/
	public Long getIndexArraySize();

	/**
	*/
	public Boolean getcontainsInfo();

	/**
	*/
	public Boolean getisInfoIndirect();

	/**
	*/
	public String getInfoType();

	/**
	*/
	public Boolean getInfoHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsLength();

	/**
	*/
	public Boolean getisLengthIndirect();

	/**
	*/
	public String getLengthType();

	/**
	*/
	public Boolean getLengthHasTypeInteger();

	/**
	*/
	public Long getLengthIntegerValue();

	/**
	*/
	public Boolean getcontainsPrev();

	/**
	*/
	public Boolean getisPrevIndirect();

	/**
	*/
	public String getPrevType();

	/**
	*/
	public Boolean getPrevHasTypeInteger();

	/**
	*/
	public Long getPrevIntegerValue();

	/**
	*/
	public Boolean getcontainsRoot();

	/**
	*/
	public Boolean getisRootIndirect();

	/**
	*/
	public String getRootType();

	/**
	*/
	public Boolean getRootHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsSize();

	/**
	*/
	public Boolean getisSizeIndirect();

	/**
	*/
	public String getSizeType();

	/**
	*/
	public Boolean getSizeHasTypeInteger();

	/**
	*/
	public Long getSizeIntegerValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getisTypeIndirect();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean getcontainsW();

	/**
	*/
	public Boolean getisWIndirect();

	/**
	*/
	public String getWType();

	/**
	*/
	public Boolean getWHasTypeArray();

	/**
	*/
	public Long getEncryptVIntegerValue();

	/**
	*/
	public Boolean getEncryptVHasTypeInteger();

	/**
	*/
	public Boolean getcontainstrailerCatalogPieceInfo();

	/**
	*/
	public Boolean getcontainstrailerInfoModDate();

	/**
	*/
	public Boolean gethasExtensionISO_TS_32004();

	/**
	*/
	public Boolean gethasExtensionOpenOffice();
}
